collect_ideals

Function collect_ideals 

pub fn collect_ideals<U: Uair>(
    num_constraints: usize,
) -> IdealCollector<U::Ideal>
Given a Uair and a hint of how many constraints it is going to have, creates an IdealCollector object and collects ideals from the Uair.